@@ -10,11 +10,13 @@
 #include <QCommandLineParser>
 #include <QCoreApplication>
 #include <QDate>
+#include <QFile>
 #include <QFutureWatcher>
 #include <QMutexLocker>
 #include <QProcess>
+#include <QStandardPaths>
 #include <QTextStream>
-#include <QtConcurrent>
+#include <QtConcurrentRun>
 
 #include <QDebug>
 
